# fundosbr - Mostra informações sobre fundos de investimentos brasileiros

![build](https://github.com/thobiast/fundosbr/workflows/build/badge.svg)
![PyPI - Python Version](https://img.shields.io/pypi/pyversions/fundosbr)
[![codecov](https://codecov.io/gh/thobiast/fundosbr/branch/master/graph/badge.svg)](https://codecov.io/gh/thobiast/fundosbr)
[![GitHub License](https://img.shields.io/github/license/thobiast/fundosbr)](https://github.com/thobiast/fundosbr/blob/master/LICENSE)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)


## Instalação

```bash
pip install fundosbr
```

Script que baixa informações direto da CVM e mostra detalhes dos fundos de investimento.

